Getting Started
###############

About
=====
Formbar is a python library to layout, render, and validate data in HTML forms
in web applications.

Installation
============
Formbar is availble on `Github <https://github.com/toirl/formbar>`_.
You can check of the source and install the library with the following
command::
        
        (venv)> git clone https://github.com/toirl/formbar.git
        (venv)> cd phormular
        (venv)> python setup.py develop # use develop for development install

.. tip::

   I recommend to install the library for testing issue in the virtual python
   environment. See `Virtualenv documentation
   <http://www.virtualenv.org/en/latest/>`_ for more details.
